==> process-kafka-quickstart-springboot-1.0.0.Final-sources.jar: defaultPackage/RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0.java <==
package defaultPackage;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.acme.travel.Traveller;
import static defaultPackage.RulesE5717FD31E01E6A14765D39787C99F47.*;

public class RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0 {

    /**
     * Rule name: Process travellers
     */
    public static org.drools.model.Rule rule_Process_32travellers() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Process travellers").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                            "travellers")
                                                                 .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                       defaultPackage.PFE.LambdaPredicateFE55FAEB374E0452CB9ED2F0CBA38EC3.INSTANCE,
                                                                                                       D.alphaIndexedBy(java.lang.Boolean.class,
                                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                        DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                        defaultPackage.PED.LambdaExtractorED7FA8BA892C2C21FB3FA68D21A73AFE.INSTANCE,
                                                                                                                        false),
                                                                                                       D.reactOn("processed")).expr("7A4D786786CA592335131B19292DCAA2",
                                                                                                                                    defaultPackage.PFB.LambdaPredicateFB0D33D21B8F4B6F86E0B6B6C576A5DD.INSTANCE,
                                                                                                                                    D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                     org.drools.model.Index.ConstraintType.NOT_EQUAL,
                                                                                                                                                     DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                     defaultPackage.PD3.LambdaExtractorD33A1642777DA894E7356045563AC333.INSTANCE,
                                                                                                                                                     "American"),
                                                                                                                                    D.reactOn("nationality")),
                                                                        D.on(var_$traveller).execute(defaultPackage.P94.LambdaConsequence941952762A597E3A1C3969F7277FF0E2.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Don't process travellers from US
     */
    public static org.drools.model.Rule rule_Don_39t_32process_32travellers_32from_32US() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Don't process travellers from US").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                                          "travellers")
                                                                               .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                                     defaultPackage.PFE.LambdaPredicateFE55FAEB374E0452CB9ED2F0CBA38EC3.INSTANCE,
                                                                                                                     D.alphaIndexedBy(java.lang.Boolean.class,
                                                                                                                                      org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                      DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                                      defaultPackage.PED.LambdaExtractorED7FA8BA892C2C21FB3FA68D21A73AFE.INSTANCE,
                                                                                                                                      false),
                                                                                                                     D.reactOn("processed")).expr("68191149A3CDE5A95B4E42CAFC6EA789",
                                                                                                                                                  defaultPackage.P44.LambdaPredicate44119AD54BB8866055F5C0D436692C46.INSTANCE,
                                                                                                                                                  D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                                   org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                                                   DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                                   defaultPackage.PD3.LambdaExtractorD33A1642777DA894E7356045563AC333.INSTANCE,
                                                                                                                                                                   "American"),
                                                                                                                                                  D.reactOn("nationality")),
                                                                                      D.on(var_$traveller).execute(defaultPackage.P7E.LambdaConsequence7E7E820C57F7F133FBE33130A44A2C11.INSTANCE));
        return rule;
    }
}

==> process-kafka-quickstart-springboot-1.2.0.Final-sources.jar: defaultPackage/RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0.java <==
package defaultPackage;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.acme.travel.Traveller;
import static defaultPackage.RulesE5717FD31E01E6A14765D39787C99F47.*;

public class RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0 {

    /**
     * Rule name: Process travellers
     */
    public static org.drools.model.Rule rule_Process_32travellers() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Process travellers").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                            "travellers")
                                                                 .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                       defaultPackage.P48.LambdaPredicate48608D694733E7D18FD2AF89AC972457.INSTANCE,
                                                                                                       D.alphaIndexedBy(boolean.class,
                                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                        DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                        defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                        false),
                                                                                                       D.reactOn("processed")).expr("7A4D786786CA592335131B19292DCAA2",
                                                                                                                                    defaultPackage.PFC.LambdaPredicateFCEF6B7EECD6B53C142B89428076C7A5.INSTANCE,
                                                                                                                                    D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                     org.drools.model.Index.ConstraintType.NOT_EQUAL,
                                                                                                                                                     DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                     defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                     "American"),
                                                                                                                                    D.reactOn("nationality")),
                                                                        D.on(var_$traveller).execute(defaultPackage.PA5.LambdaConsequenceA5A36002EBFB0332B66CB8F03C337FB4.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Don't process travellers from US
     */
    public static org.drools.model.Rule rule_Don_39t_32process_32travellers_32from_32US() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Don't process travellers from US").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                                          "travellers")
                                                                               .build(D.pattern(var_$traveller).expr("1431ED0539270BF7254590AD8439205F",
                                                                                                                     defaultPackage.P48.LambdaPredicate48608D694733E7D18FD2AF89AC972457.INSTANCE,
                                                                                                                     D.alphaIndexedBy(boolean.class,
                                                                                                                                      org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                      DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                                      defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                                      false),
                                                                                                                     D.reactOn("processed")).expr("68191149A3CDE5A95B4E42CAFC6EA789",
                                                                                                                                                  defaultPackage.P36.LambdaPredicate361032097D33DCCAD444B86B258F06BB.INSTANCE,
                                                                                                                                                  D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                                   org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                                                   DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                                   defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                                   "American"),
                                                                                                                                                  D.reactOn("nationality")),
                                                                                      D.on(var_$traveller).execute(defaultPackage.PDE.LambdaConsequenceDE16905015D6A6C568A5CE1303BC02DF.INSTANCE));
        return rule;
    }
}
